set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_050000 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2013.01.01'
,p_release=>'5.0.4.00.12'
,p_default_workspace_id=>69160808430820669492
,p_default_application_id=>35087
,p_default_owner=>'JK64'
);
end;
/
prompt --application/ui_types
begin
null;
end;
/
prompt --application/shared_components/plugins/dynamic_action/com_mailgun_email_validator
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(83529544388083634568)
,p_plugin_type=>'DYNAMIC ACTION'
,p_name=>'COM.MAILGUN_EMAIL_VALIDATOR'
,p_display_name=>'Mailgun Email Validator'
,p_category=>'INIT'
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_plsql_code=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'function init_email_validator',
'  (p_dynamic_action in apex_plugin.t_dynamic_action',
'  ,p_plugin         in apex_plugin.t_plugin)',
'  return apex_plugin.t_dynamic_action_render_result is',
'  l_result      apex_plugin.t_dynamic_action_render_result;',
'  l_api_key     varchar2(500)  := p_plugin.attribute_01;',
'  l_show_result varchar(1)     := p_dynamic_action.attribute_01;',
'  l_msg_invalid varchar2(4000) := p_dynamic_action.attribute_02;',
'begin',
'  apex_plugin_util.debug_dynamic_action',
'    (p_plugin         => p_plugin',
'    ,p_dynamic_action => p_dynamic_action);',
'  apex_javascript.add_library',
'    (p_name                  => ''mailgun_validator''',
'    ,p_directory             => p_plugin.file_prefix',
'    ,p_check_to_add_minified => true);',
'  apex_javascript.add_library',
'    (p_name                  => ''apexmailgun''',
'    ,p_directory             => p_plugin.file_prefix',
'    ,p_check_to_add_minified => true);',
'  apex_css.add_file',
'    (p_name                  => ''apexmailgun''',
'    ,p_directory             => p_plugin.file_prefix);',
'  l_result.javascript_function := ''mailgun.init'';',
'  l_result.attribute_01        := l_api_key;',
'  l_result.attribute_02        := p_plugin.file_prefix;',
'  l_result.attribute_03        := l_show_result;',
'  l_result.attribute_04        := l_msg_invalid;',
'  return l_result;',
'end init_email_validator;'))
,p_render_function=>'init_email_validator'
,p_standard_attributes=>'ITEM:JQUERY_SELECTOR:TRIGGERING_ELEMENT:REQUIRED'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_version_identifier=>'1.1 Portuguese'
,p_plugin_comment=>wwv_flow_utilities.join(wwv_flow_t_varchar2(
'Created by Jeff Kemp using Mailgun''s jQuery email validator (https://github.com/mailgun/validator-demo). <a href="http://www.mailgun.com">Mailgun</a> is © Rackspace, US Inc.',
'',
'Translation to Portuguese provided thanks to Abreu Retto.'))
,p_files_version=>43
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(83529545597469724707)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_attribute_scope=>'APPLICATION'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Mailgun Public API Key'
,p_attribute_type=>'TEXT'
,p_is_required=>true
,p_display_length=>50
,p_max_length=>100
,p_is_translatable=>false
,p_help_text=>'Get your Mailgun Public API Key from https://mailgun.com. Warning: don''t use your private key!'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(83529582975764950333)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Show Validation Result'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'Y'
,p_is_translatable=>false
,p_help_text=>'Adds a span immediately after the item where the loading icon, success and error indicators and messages will be shown. Set this to No if you are going to use the plugin triggers to implement your own handling and display of the validation results.'
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(83529587273230138126)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Message when address is invalid'
,p_attribute_type=>'TEXT'
,p_is_required=>true
,p_default_value=>'Address is invalid.'
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(83529582975764950333)
,p_depending_on_condition_type=>'EQUALS'
,p_depending_on_expression=>'Y'
,p_help_text=>'Message text to show if email fails validation.'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(83529582209263929039)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_name=>'validationerror'
,p_display_name=>'validationError'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(83529581515741929038)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_name=>'validationinprogress'
,p_display_name=>'validationInProgress'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(83529581872865929038)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_name=>'validationsuccess'
,p_display_name=>'validationSuccess'
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2166756E6374696F6E2865297B66756E6374696F6E207328732C612C72297B696628722E6D61696C67756E52657175657374262628722E6D61696C67756E526571756573742E61626F727428292C722E6D61696C67756E526571756573743D6E756C6C29';
wwv_flow_api.g_varchar2_table(2) := '2C73297B696628612626612E696E5F70726F67726573732626612E696E5F70726F677265737328612E65292C722E6D61696C67756E4C6173745375636365737352657475726E2626733D3D722E6D61696C67756E4C617374537563636573735265747572';
wwv_flow_api.g_varchar2_table(3) := '6E2E616464726573732972657475726E20766F696428612626612E737563636573732626612E7375636365737328722E6D61696C67756E4C6173745375636365737352657475726E2C612E6529293B766172206F3D21313B696628732E6C656E6774683E';
wwv_flow_api.g_varchar2_table(4) := '3531323F6F3D22456D61696C20616464726573732065786365656473206D617869756D756D20616C6C6F7761626C65206C656E677468206F66203531322E223A31213D3D732E73706C697428224022292E6C656E6774682D312626286F3D22452D6D6169';
wwv_flow_api.g_varchar2_table(5) := '6C2070726563697361207465722070656C6F206D656E6F7320756D6120402E22292C6F2972657475726E20766F696428612626612E6572726F723F612E6572726F72286F2C612E65293A636F6E736F6C652626636F6E736F6C652E6C6F67286F29293B61';
wwv_flow_api.g_varchar2_table(6) := '2626766F696420303D3D612E6170695F6B65792626636F6E736F6C652626636F6E736F6C652E6C6F6728224EE36F20666F6920706F7373ED76656C2076657269666963617220612076616C6964616465206465737465206573746520652D6D61696C2E22';
wwv_flow_api.g_varchar2_table(7) := '293B766172206E3D73657454696D656F75742866756E6374696F6E28297B6F3D224EE36F20666F6920706F7373ED76656C2076657269666963617220612076616C6964616465206465737465206573746520652D6D61696C2E222C737563636573737C7C';
wwv_flow_api.g_varchar2_table(8) := '28722E6D61696C67756E52657175657374262628722E6D61696C67756E526571756573742E61626F727428292C722E6D61696C67756E526571756573743D6E756C6C292C612626612E6572726F723F612E6572726F72286F2C612E65293A636F6E736F6C';
wwv_flow_api.g_varchar2_table(9) := '652626636F6E736F6C652E6C6F67286F29297D2C336534293B722E6D61696C67756E526571756573743D652E616A6178287B747970653A22474554222C75726C3A2268747470733A2F2F6170692E6D61696C67756E2E6E65742F76322F61646472657373';
wwv_flow_api.g_varchar2_table(10) := '2F76616C69646174653F63616C6C6261636B3D3F222C646174613A7B616464726573733A732C6170695F6B65793A612E6170695F6B65797D2C64617461547970653A226A736F6E70222C63726F7373446F6D61696E3A21302C737563636573733A66756E';
wwv_flow_api.g_varchar2_table(11) := '6374696F6E28652C73297B636C65617254696D656F7574286E292C722E6D61696C67756E4C6173745375636365737352657475726E3D652C612626612E737563636573732626612E7375636365737328652C612E65297D2C6572726F723A66756E637469';
wwv_flow_api.g_varchar2_table(12) := '6F6E28652C732C72297B636C65617254696D656F7574286E292C6F3D224EE36F20666F6920706F7373ED76656C2076657269666963617220612076616C6964616465206465737465206573746520652D6D61696C2E222C612626612E6572726F723F612E';
wwv_flow_api.g_varchar2_table(13) := '6572726F72286F2C612E65293A636F6E736F6C652626636F6E736F6C652E6C6F67286F297D7D297D7D652E666E2E6D61696C67756E5F76616C696461746F723D66756E6374696F6E2861297B72657475726E20746869732E656163682866756E6374696F';
wwv_flow_api.g_varchar2_table(14) := '6E28297B76617220723D652874686973293B722E666F6375736F75742866756E6374696F6E286F297B766172206E3D722E76616C28293B6E3D652E7472696D286E292C722E76616C286E292C612E653D6F2C73286E2C612C72297D297D297D7D286A5175';
wwv_flow_api.g_varchar2_table(15) := '657279293B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(83529544705633658425)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_file_name=>'mailgun_validator.min.js'
,p_mime_type=>'text/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2F2F0D0A2F2F204D61696C67756E20416464726573732056616C69646174696F6E20506C7567696E0D0A2F2F0D0A2F2F20417474616368696E6720746F206120666F726D3A0D0A2F2F0D0A2F2F202020202428276A71756572795F73656C6563746F7227';
wwv_flow_api.g_varchar2_table(2) := '292E6D61696C67756E5F76616C696461746F72287B0D0A2F2F20202020202020206170695F6B65793A20276170692D6B6579272C0D0A2F2F2020202020202020696E5F70726F67726573733A20696E5F70726F67726573735F63616C6C6261636B2C202F';
wwv_flow_api.g_varchar2_table(3) := '2F2063616C6C6564207768656E2072657175657374206973206D61646520746F2076616C696461746F720D0A2F2F2020202020202020737563636573733A20737563636573735F63616C6C6261636B2C2020202020202020202F2F2063616C6C65642077';
wwv_flow_api.g_varchar2_table(4) := '68656E2076616C696461746F72206861732072657475726E65640D0A2F2F20202020202020206572726F723A2076616C69646174696F6E5F6572726F722C20202020202020202020202F2F2063616C6C6564207768656E20616E206572726F7220726561';
wwv_flow_api.g_varchar2_table(5) := '6368696E67207468652076616C696461746F7220686173206F6363757265640D0A2F2F202020207D293B0D0A2F2F0D0A2F2F0D0A2F2F2053616D706C65204A534F4E20696E20737563636573732063616C6C6261636B3A0D0A2F2F0D0A2F2F20207B0D0A';
wwv_flow_api.g_varchar2_table(6) := '2F2F2020202020202269735F76616C6964223A20747275652C0D0A2F2F202020202020227061727473223A207B0D0A2F2F20202020202020202020226C6F63616C5F70617274223A20226A6F686E2E736D697468406578616D706C652E636F6D222C0D0A';
wwv_flow_api.g_varchar2_table(7) := '2F2F2020202020202020202022646F6D61696E223A20226578616D706C652E636F6D222C0D0A2F2F2020202020202020202022646973706C61795F6E616D65223A2022220D0A2F2F2020202020207D2C0D0A2F2F2020202020202261646472657373223A';
wwv_flow_api.g_varchar2_table(8) := '20226A6F686E2E736D697468406578616D706C652E636F6D222C0D0A2F2F202020202020226469645F796F755F6D65616E223A206E756C6C0D0A2F2F20207D0D0A2F2F0D0A2F2F204D6F7265204150492064657461696C733A2068747470733A2F2F6170';
wwv_flow_api.g_varchar2_table(9) := '692E6D61696C67756E2E6E65742F76322F616464726573730D0A2F2F0D0A0D0A2866756E6374696F6E2820242029207B0D0A20202020242E666E2E6D61696C67756E5F76616C696461746F72203D2066756E6374696F6E286F7074696F6E7329207B0D0A';
wwv_flow_api.g_varchar2_table(10) := '202020202020202072657475726E20746869732E656163682866756E6374696F6E2829207B0D0A2020202020202020202020207661722074686973456C656D656E74203D20242874686973293B0D0A20202020202020202020202074686973456C656D65';
wwv_flow_api.g_varchar2_table(11) := '6E742E666F6375736F75742866756E6374696F6E286529207B0D0A202020202020202020202020202020202F2F5472696D20737472696E6720616E64206175746F636F72726563742077686974657370616365206973737565730D0A2020202020202020';
wwv_flow_api.g_varchar2_table(12) := '202020202020202076617220656C656D656E7456616C7565203D2074686973456C656D656E742E76616C28293B0D0A20202020202020202020202020202020656C656D656E7456616C7565203D20242E7472696D28656C656D656E7456616C7565293B0D';
wwv_flow_api.g_varchar2_table(13) := '0A2020202020202020202020202020202074686973456C656D656E742E76616C28656C656D656E7456616C7565293B0D0A0D0A202020202020202020202020202020202F2F417474616368206576656E7420746F206F7074696F6E730D0A202020202020';
wwv_flow_api.g_varchar2_table(14) := '202020202020202020206F7074696F6E732E65203D20653B0D0A0D0A2020202020202020202020202020202072756E5F76616C696461746F7228656C656D656E7456616C75652C206F7074696F6E732C2074686973456C656D656E74293B0D0A20202020';
wwv_flow_api.g_varchar2_table(15) := '20202020202020207D293B0D0A20202020202020207D293B0D0A202020207D3B0D0A0D0A2020202066756E6374696F6E2072756E5F76616C696461746F7228616464726573735F746578742C206F7074696F6E732C20656C656D656E7429207B0D0A2020';
wwv_flow_api.g_varchar2_table(16) := '2020202020202F2F41626F7274206578697374696E6720414A4158205265717565737420746F2070726576656E7420666C6F6F64696E670D0A2020202020202020696628656C656D656E742E6D61696C67756E5265717565737429207B0D0A2020202020';
wwv_flow_api.g_varchar2_table(17) := '20202020202020656C656D656E742E6D61696C67756E526571756573742E61626F727428293B0D0A202020202020202020202020656C656D656E742E6D61696C67756E52657175657374203D206E756C6C3B0D0A20202020202020207D0D0A0D0A202020';
wwv_flow_api.g_varchar2_table(18) := '20202020202F2F20646F6E27742072756E2076616C696461746F7220776974686F757420696E7075740D0A20202020202020206966202821616464726573735F7465787429207B0D0A20202020202020202020202072657475726E3B0D0A202020202020';
wwv_flow_api.g_varchar2_table(19) := '20207D0D0A0D0A20202020202020202F2F2076616C696461746F7220697320696E2070726F67726573730D0A2020202020202020696620286F7074696F6E73202626206F7074696F6E732E696E5F70726F677265737329207B0D0A202020202020202020';
wwv_flow_api.g_varchar2_table(20) := '2020206F7074696F6E732E696E5F70726F6772657373286F7074696F6E732E65293B0D0A20202020202020207D0D0A0D0A20202020202020202F2F20646F6E27742072756E2064757069636174652063616C6C730D0A202020202020202069662028656C';
wwv_flow_api.g_varchar2_table(21) := '656D656E742E6D61696C67756E4C6173745375636365737352657475726E29207B0D0A20202020202020202020202069662028616464726573735F74657874203D3D20656C656D656E742E6D61696C67756E4C6173745375636365737352657475726E2E';
wwv_flow_api.g_varchar2_table(22) := '6164647265737329207B0D0A20202020202020202020202020202020696620286F7074696F6E73202626206F7074696F6E732E7375636365737329207B0D0A20202020202020202020202020202020202020206F7074696F6E732E737563636573732865';
wwv_flow_api.g_varchar2_table(23) := '6C656D656E742E6D61696C67756E4C6173745375636365737352657475726E2C206F7074696F6E732E65293B0D0A202020202020202020202020202020207D0D0A2020202020202020202020202020202072657475726E3B0D0A20202020202020202020';
wwv_flow_api.g_varchar2_table(24) := '20207D0D0A20202020202020207D0D0A0D0A20202020202020202F2F206C656E67746820616E6420402073796E74617820636865636B0D0A2020202020202020766172206572726F725F6D657373616765203D2066616C73653B0D0A2020202020202020';
wwv_flow_api.g_varchar2_table(25) := '69662028616464726573735F746578742E6C656E677468203E20353132290D0A2020202020202020202020206572726F725F6D657373616765203D2027456D61696C20616464726573732065786365656473206D617869756D756D20616C6C6F7761626C';
wwv_flow_api.g_varchar2_table(26) := '65206C656E677468206F66203531322E273B0D0A2020202020202020656C736520696620283120213D3D20616464726573735F746578742E73706C697428274027292E6C656E6774682D31290D0A2020202020202020202020206572726F725F6D657373';
wwv_flow_api.g_varchar2_table(27) := '616765203D2027452D6D61696C206465766520636F6E7465722070656C6F206D656E6F7320756D6120402E273B0D0A0D0A2020202020202020696620286572726F725F6D65737361676529207B0D0A202020202020202020202020696620286F7074696F';
wwv_flow_api.g_varchar2_table(28) := '6E73202626206F7074696F6E732E6572726F7229207B0D0A202020202020202020202020202020206F7074696F6E732E6572726F72286572726F725F6D6573736167652C206F7074696F6E732E65293B0D0A2020202020202020202020207D0D0A202020';
wwv_flow_api.g_varchar2_table(29) := '202020202020202020656C7365207B0D0A2020202020202020202020202020202069662028636F6E736F6C652920636F6E736F6C652E6C6F67286572726F725F6D657373616765293B0D0A2020202020202020202020207D0D0A20202020202020202020';
wwv_flow_api.g_varchar2_table(30) := '202072657475726E3B0D0A20202020202020207D0D0A0D0A20202020202020202F2F207265717569726520617069206B65790D0A2020202020202020696620286F7074696F6E73202626206F7074696F6E732E6170695F6B6579203D3D20756E64656669';
wwv_flow_api.g_varchar2_table(31) := '6E656429207B0D0A20202020202020202020202069662028636F6E736F6C652920636F6E736F6C652E6C6F6728274EE36F20666F6920706F7373ED76656C2076657269666963617220612076616C6964616465206465737465206573746520652D6D6169';
wwv_flow_api.g_varchar2_table(32) := '6C2E27293B0D0A20202020202020207D0D0A0D0A20202020202020202F2F2074696D656F757420696E63617365206F6620736F6D65206B696E64206F6620696E7465726E616C20736572766572206572726F720D0A20202020202020207661722074696D';
wwv_flow_api.g_varchar2_table(33) := '656F75744944203D2073657454696D656F75742866756E6374696F6E2829207B0D0A2020202020202020202020206572726F725F6D657373616765203D20274EE36F20666F6920706F7373ED76656C2076657269666963617220612076616C6964616465';
wwv_flow_api.g_varchar2_table(34) := '206465737465206573746520652D6D61696C2E273B0D0A20202020202020202020202069662028217375636365737329207B0D0A202020202020202020202020202020202F2F41626F7274206578697374696E6720414A4158205265717565737420666F';
wwv_flow_api.g_varchar2_table(35) := '72206120747275652074696D656F75740D0A20202020202020202020202020202020696628656C656D656E742E6D61696C67756E5265717565737429207B0D0A2020202020202020202020202020202020202020656C656D656E742E6D61696C67756E52';
wwv_flow_api.g_varchar2_table(36) := '6571756573742E61626F727428293B0D0A2020202020202020202020202020202020202020656C656D656E742E6D61696C67756E52657175657374203D206E756C6C3B0D0A202020202020202020202020202020207D0D0A0D0A20202020202020202020';
wwv_flow_api.g_varchar2_table(37) := '202020202020696620286F7074696F6E73202626206F7074696F6E732E6572726F7229207B0D0A20202020202020202020202020202020202020206F7074696F6E732E6572726F72286572726F725F6D6573736167652C206F7074696F6E732E65293B0D';
wwv_flow_api.g_varchar2_table(38) := '0A202020202020202020202020202020207D0D0A20202020202020202020202020202020656C7365207B0D0A202020202020202020202020202020202020202069662028636F6E736F6C652920636F6E736F6C652E6C6F67286572726F725F6D65737361';
wwv_flow_api.g_varchar2_table(39) := '6765293B0D0A202020202020202020202020202020207D0D0A2020202020202020202020207D0D0A20202020202020207D2C203330303030293B202F2F3330207365636F6E64730D0A0D0A20202020202020202F2F206D616B6520616A61782063616C6C';
wwv_flow_api.g_varchar2_table(40) := '20746F206765742076616C69646174696F6E20726573756C74730D0A2020202020202020656C656D656E742E6D61696C67756E52657175657374203D20242E616A6178287B0D0A202020202020202020202020747970653A2022474554222C0D0A202020';
wwv_flow_api.g_varchar2_table(41) := '20202020202020202075726C3A202768747470733A2F2F6170692E6D61696C67756E2E6E65742F76322F616464726573732F76616C69646174653F63616C6C6261636B3D3F272C0D0A202020202020202020202020646174613A207B2061646472657373';
wwv_flow_api.g_varchar2_table(42) := '3A20616464726573735F746578742C206170695F6B65793A206F7074696F6E732E6170695F6B6579207D2C0D0A20202020202020202020202064617461547970653A20226A736F6E70222C0D0A20202020202020202020202063726F7373446F6D61696E';
wwv_flow_api.g_varchar2_table(43) := '3A20747275652C0D0A202020202020202020202020737563636573733A2066756E6374696F6E28646174612C207374617475735F7465787429207B0D0A20202020202020202020202020202020636C65617254696D656F75742874696D656F7574494429';
wwv_flow_api.g_varchar2_table(44) := '3B0D0A0D0A20202020202020202020202020202020656C656D656E742E6D61696C67756E4C6173745375636365737352657475726E203D20646174613B0D0A20202020202020202020202020202020696620286F7074696F6E73202626206F7074696F6E';
wwv_flow_api.g_varchar2_table(45) := '732E7375636365737329207B0D0A20202020202020202020202020202020202020206F7074696F6E732E7375636365737328646174612C206F7074696F6E732E65293B0D0A202020202020202020202020202020207D0D0A202020202020202020202020';
wwv_flow_api.g_varchar2_table(46) := '7D2C0D0A2020202020202020202020206572726F723A2066756E6374696F6E28726571756573742C207374617475735F746578742C206572726F7229207B0D0A20202020202020202020202020202020636C65617254696D656F75742874696D656F7574';
wwv_flow_api.g_varchar2_table(47) := '4944293B0D0A202020202020202020202020202020206572726F725F6D657373616765203D20274EE36F20666F6920706F7373ED76656C2076657269666963617220612076616C6964616465206465737465206573746520652D6D61696C2E273B0D0A0D';
wwv_flow_api.g_varchar2_table(48) := '0A20202020202020202020202020202020696620286F7074696F6E73202626206F7074696F6E732E6572726F7229207B0D0A20202020202020202020202020202020202020206F7074696F6E732E6572726F72286572726F725F6D6573736167652C206F';
wwv_flow_api.g_varchar2_table(49) := '7074696F6E732E65293B0D0A202020202020202020202020202020207D0D0A20202020202020202020202020202020656C7365207B0D0A202020202020202020202020202020202020202069662028636F6E736F6C652920636F6E736F6C652E6C6F6728';
wwv_flow_api.g_varchar2_table(50) := '6572726F725F6D657373616765293B0D0A202020202020202020202020202020207D0D0A2020202020202020202020207D0D0A20202020202020207D293B0D0A202020207D0D0A7D2928206A517565727920293B0D0A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(83529545154243659115)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_file_name=>'mailgun_validator.js'
,p_mime_type=>'text/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '766172206D61696C67756E203D207B0A0A717569636B5069636B203A2066756E6374696F6E20287468697349642C20616C7465726E61746529207B0A202072657475726E20273C6120687265663D226A6176617363726970743A24285C272327202B2074';
wwv_flow_api.g_varchar2_table(2) := '6869734964202B20275C2729270A202020202020202B20272E76616C285C2727202B20616C7465726E617465202B20275C2729270A0920202020202B20272E666F6375736F757428293B223E270A0920202020202B20616C7465726E617465202B20273C';
wwv_flow_api.g_varchar2_table(3) := '2F613E273B0A7D2C0A0A6765745F73756767657374696F6E5F737472203A2066756E6374696F6E20287468697349642C2069735F76616C69642C20616C7465726E6174652C206D7367496E76616C696429207B0A20206966202869735F76616C69642920';
wwv_flow_api.g_varchar2_table(4) := '7B0A2020202076617220726573756C74203D20273C7370616E20636C6173733D226D61696C67756E5375636365737349636F6E2066612066612D636865636B222F3E273B0A2020202069662028616C7465726E61746529207B0A20202020202072657375';
wwv_flow_api.g_varchar2_table(5) := '6C74202B3D2027203C7370616E20636C6173733D226D61696C67756E53756767657374696F6E223E270A20202020202020202020202020202B20272874686F7567682064696420796F75206D65616E2027202B206D61696C67756E2E717569636B506963';
wwv_flow_api.g_varchar2_table(6) := '6B287468697349642C616C7465726E61746529202B20273F29270A20202020202020202020202020202B20273C2F7370616E3E273B0A202020207D0A2020202072657475726E20726573756C740A20207D20656C73652069662028616C7465726E617465';
wwv_flow_api.g_varchar2_table(7) := '29207B0A2020202072657475726E20273C7370616E20636C6173733D226D61696C67756E5175657374696F6E49636F6E2066612066612D7761726E696E67222F3E270A2020202020202020202B2027203C7370616E20636C6173733D226D61696C67756E';
wwv_flow_api.g_varchar2_table(8) := '53756767657374696F6E223E270A2020202020202020202B202744696420796F75206D65616E2027202B206D61696C67756E2E717569636B5069636B287468697349642C616C7465726E61746529202B20273F270A2020202020202020202B20273C2F73';
wwv_flow_api.g_varchar2_table(9) := '70616E3E273B0A20207D20656C7365207B0A2020202072657475726E20273C7370616E20636C6173733D226D61696C67756E4572726F7249636F6E2066612066612D636C6F7365222F3E270A2020202020202020202B20273C7370616E20636C6173733D';
wwv_flow_api.g_varchar2_table(10) := '226D61696C67756E4572726F72223E27202B206D7367496E76616C6964202B20273C2F7370616E3E273B0A20207D0A7D2C0A0A76616C69646174696F6E5F696E5F70726F6772657373203A2066756E6374696F6E2028652C2066696C6550726566697829';
wwv_flow_api.g_varchar2_table(11) := '207B0A20202F2F206177616974696E6720726573756C7420666F722076616C69646174696F6E0A202076617220746869734964203D202428652E746172676574292E617474722822696422292C0A2020202020207265734964203D207468697349642B22';
wwv_flow_api.g_varchar2_table(12) := '5F726573756C74223B0A2020617065782E64656275672822617065786D61696C67756E3A2076616C69646174696F6E5F696E5F70726F67726573732022202B207265734964293B0A202024282223222B7265734964292E68746D6C28223C696D6720636C';
wwv_flow_api.g_varchar2_table(13) := '6173733D276D61696C67756E4C6F6164696E6749636F6E27220A2020202020202020202020202020202020202B2022207372633D2722202B2066696C65507265666978202B2022616A61782D6C6F616465722E67696627220A2020202020202020202020';
wwv_flow_api.g_varchar2_table(14) := '202020202020202B2022206865696768743D273136272F3E22293B0A2020617065782E64656275672822747269676765722076616C69646174696F6E696E70726F677265737322293B0A2020617065782E6A5175657279282223222B746869734964292E';
wwv_flow_api.g_varchar2_table(15) := '74726967676572282276616C69646174696F6E696E70726F677265737322293B0A7D2C0A0A76616C69646174696F6E5F73756363657373203A2066756E6374696F6E2028646174612C20652C206D7367696E76616C696429207B0A20202F2F2076616C69';
wwv_flow_api.g_varchar2_table(16) := '646174696F6E207375636365656465640A202076617220746869734964203D202428652E746172676574292E617474722822696422292C0A2020202020207265734964203D207468697349642B225F726573756C74223B0A2020617065782E6465627567';
wwv_flow_api.g_varchar2_table(17) := '2822617065786D61696C67756E3A2076616C69646174696F6E5F737563636573732022202B207265734964293B0A202024282223222B7265734964292E68746D6C280A202020206D61696C67756E2E6765745F73756767657374696F6E5F737472287468';
wwv_flow_api.g_varchar2_table(18) := '697349642C20646174615B2769735F76616C6964275D2C20646174615B276469645F796F755F6D65616E275D2C206D7367696E76616C6964290A2020293B0A2020617065782E64656275672822747269676765722076616C69646174696F6E7375636365';
wwv_flow_api.g_varchar2_table(19) := '737322293B0A2020617065782E6A5175657279282223222B746869734964292E74726967676572282276616C69646174696F6E73756363657373222C207B646174613A646174617D293B0A7D2C0A0A76616C69646174696F6E5F6572726F72203A206675';
wwv_flow_api.g_varchar2_table(20) := '6E6374696F6E20286572726F725F6D6573736167652C206529207B0A20202F2F2076616C69646174696F6E206661696C65640A202076617220746869734964203D202428652E746172676574292E617474722822696422292C0A20202020202072657349';
wwv_flow_api.g_varchar2_table(21) := '64203D207468697349642B225F726573756C74223B0A2020617065782E64656275672822617065786D61696C67756E3A2076616C69646174696F6E5F6572726F722022202B207265734964293B0A202024282223222B7265734964292E68746D6C28273C';
wwv_flow_api.g_varchar2_table(22) := '7370616E20636C6173733D226D61696C67756E4572726F7249636F6E2066612066612D636C6F7365222F3E270A2020202020202020202020202020202020202B2027203C7370616E20636C6173733D226D61696C67756E4572726F72223E270A20202020';
wwv_flow_api.g_varchar2_table(23) := '20202020202020202020202020202B206572726F725F6D6573736167650A2020202020202020202020202020202020202B20273C2F7370616E3E27293B0A2020617065782E64656275672822747269676765722076616C69646174696F6E6572726F7222';
wwv_flow_api.g_varchar2_table(24) := '293B0A2020617065782E6A5175657279282223222B746869734964292E74726967676572282276616C69646174696F6E6572726F72222C207B6572726F724D6573736167653A6572726F725F6D6573736167657D293B0A7D2C0A0A6F6E5F6368616E6765';
wwv_flow_api.g_varchar2_table(25) := '203A2066756E6374696F6E20286529207B0A202076617220746869734964203D202428652E746172676574292E617474722822696422292C0A2020202020207265734964203D207468697349642B225F726573756C74223B0A2020617065782E64656275';
wwv_flow_api.g_varchar2_table(26) := '672822617065786D61696C67756E3A206F6E5F6368616E67652022202B207265734964202B20273D22272B24282223222B746869734964292E76616C28292B272227293B0A20206966202824282223222B746869734964292E76616C28293D3D22222920';
wwv_flow_api.g_varchar2_table(27) := '7B0A202020202F2F20636C65617220616E79206F6C64206572726F72206D657373616765730A20202020617065782E64656275672822636C656172696E6720726573756C7422293B0A2020202024282223222B7265734964292E68746D6C282222293B0A';
wwv_flow_api.g_varchar2_table(28) := '20207D0A7D2C0A0A696E6974203A2066756E6374696F6E2829207B0A202076617220646154686973203D20746869732C0A20202020202076456C656D656E74734172726179203D206461546869732E6166666563746564456C656D656E74732C0A202020';
wwv_flow_api.g_varchar2_table(29) := '202020764170694B6579203D206461546869732E616374696F6E2E61747472696275746530312C0A2020202020207646696C65507265666978203D206461546869732E616374696F6E2E61747472696275746530322C0A2020202020207653686F775265';
wwv_flow_api.g_varchar2_table(30) := '73756C74203D206461546869732E616374696F6E2E61747472696275746530332C0A202020202020764D7367496E76616C6964203D206461546869732E616374696F6E2E61747472696275746530343B0A2020617065782E64656275672827617065786D';
wwv_flow_api.g_varchar2_table(31) := '61696C67756E3A206166666563746564456C656D656E74733A27202B2076456C656D656E747341727261792E6C656E677468293B0A2020617065782E64656275672827617065786D61696C67756E3A20764170694B65793D27202B20764170694B657929';
wwv_flow_api.g_varchar2_table(32) := '3B0A2020617065782E64656275672827617065786D61696C67756E3A207646696C655072656669783D27202B207646696C65507265666978293B0A2020666F7220287661722069203D20303B2069203C2076456C656D656E747341727261792E6C656E67';
wwv_flow_api.g_varchar2_table(33) := '74683B20692B2B29207B0A2020202076617220766166666563746564456C656D656E74203D206461546869732E6166666563746564456C656D656E74732E65712869292C0A2020202020202020746869734964203D202428766166666563746564456C65';
wwv_flow_api.g_varchar2_table(34) := '6D656E74292E617474722822696422293B0A20202020696620287653686F77526573756C743D3D22592229207B0A202020202020617065782E64656275672822617065786D61696C67756E3A20616464696E6720726573756C74207370616E2022202B20';
wwv_flow_api.g_varchar2_table(35) := '746869734964293B0A202020202020766172207265734964203D207468697349642B225F726573756C74223B0A2020202020202428766166666563746564456C656D656E74292E616674657228223C7370616E20636C6173733D276D61696C67756E5265';
wwv_flow_api.g_varchar2_table(36) := '73756C74272069643D27222B72657349642B22273E3C2F7370616E3E22293B0A202020090924282223222B746869734964292E6368616E67652866756E6374696F6E2865297B0A09090920206D61696C67756E2E6F6E5F6368616E67652865293B0A0909';
wwv_flow_api.g_varchar2_table(37) := '20207D293B0A202020207D0A2020617065782E64656275672822617065786D61696C67756E3A206170706C79696E67206D61696C67756E2076616C696461746F722022202B20746869734964293B0A20202428766166666563746564456C656D656E7429';
wwv_flow_api.g_varchar2_table(38) := '2E6D61696C67756E5F76616C696461746F72287B0A202020206170695F6B65793A20764170694B65792C0A20202020696E5F70726F67726573733A2066756E6374696F6E286529207B0A2020202020206D61696C67756E2E76616C69646174696F6E5F69';
wwv_flow_api.g_varchar2_table(39) := '6E5F70726F677265737328652C207646696C65507265666978293B0A202020207D2C0A20202020737563636573733A2066756E6374696F6E28646174612C206529207B0A2020202020206D61696C67756E2E76616C69646174696F6E5F73756363657373';
wwv_flow_api.g_varchar2_table(40) := '28646174612C20652C20764D7367496E76616C6964293B0A202020207D2C0A202020206572726F723A2066756E6374696F6E20286572726F725F6D6573736167652C206529207B0A2020202020206D61696C67756E2E76616C69646174696F6E5F657272';
wwv_flow_api.g_varchar2_table(41) := '6F72286572726F725F6D6573736167652C2065293B0A202020207D0A20207D293B0A7D0A7D0A0A7D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(83529576877606575753)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_file_name=>'apexmailgun.js'
,p_mime_type=>'text/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '47494638396119001900870000222222444444666666888888AAAAAACCCCCCDDDDDDEEEEEEFFFFFF000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(2) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(3) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(4) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(5) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(6) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(7) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
wwv_flow_api.g_varchar2_table(8) := '00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000021FF0B4E45545343415045322E300301000000';
wwv_flow_api.g_varchar2_table(9) := '21F904030F0008002C00000000190019000008A80011081C48B0A0C1830703280C80B0E1C0850B1D0E1440518040880A0502D808C060C58A083032E4C8B1E0478A21312220B9D1E4C98B1157B274F91121CB8E342D362429B1E7C1014007F84470A0E801';
wwv_flow_api.g_varchar2_table(10) := '814183F6346A144152A04B991E7D2A54A2D4A94FA33245AAD4E7D6A160098825E0D080590306C78E4578F66C41B5620516985B40605BB36FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C0000';
wwv_flow_api.g_varchar2_table(11) := '0000190019000008A80011081C48B0A0C1830705281480B0E1C0850B1D0E1C40718040880A0506D818C060C58A083032E4C8B1E0478A21312220B9D1E4C98B1157B274F91121CB8E342D362429B1E741024009F84400A02800814183F6346A144152A04B';
wwv_flow_api.g_varchar2_table(12) := '991E7D2A54A2D4A94FA33245AAD4E7D6A1600B882DE0F080D90306C78E4578F66C41B562051A986B40605BB36FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C00000000190019000008A80011';
wwv_flow_api.g_varchar2_table(13) := '081C48B0A0C1830707281C80B0E1C0850B1D0E2440918040880A050AD828C060C58A083032E4C8B1E0478A21312220B9D1E4C98B1157B274F91121CB8E342D362429B1E7C102400BF84410A06800814183F6346A144152A04B991E7D2A54A2D4A94FA332';
wwv_flow_api.g_varchar2_table(14) := '45AAD4E7D6A1600D8835E01080590006C78E4578F66C41B562051E987B40605BB36FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C00000000190019000008A80011081C48B0A0C18307092824';
wwv_flow_api.g_varchar2_table(15) := '80B0E1C0850B1D0E2C40B18040880A050ED838C060C58A083032E4C8B1E0478A21312220B9D1E4C98B1157B274F91121CB8E342D362429B1E74103400DF84420A0A800814183F6346A144152A04B991E7D2A54A2D4A94FA33245AAD4E7D6A1600F883DE0';
wwv_flow_api.g_varchar2_table(16) := '3080D90006C78E4578F66C41B5620502980B40605BB36FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C00000000190019000008A80011081C48B0A0C183070B282C80B0E1C0850B1D0E3440D1';
wwv_flow_api.g_varchar2_table(17) := '8040880A0512D848C060C58A083032E4C8B1E0478A21312220B9D1E4C98B1157B274F91121CB8E342D362429B1E7C103400FF84430A0E800814183F6346A144152A04B991E7D2A54A2D4A94FA33245AAD4E7D6A160018805E05080590106C78E4578F66C';
wwv_flow_api.g_varchar2_table(18) := '41B5620506981B40605BB36FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C00000000190019000008A80011081C48B0A0C183070D283480B0E1C0850B1D0E3C40F18040880A0516D858C060C5';
wwv_flow_api.g_varchar2_table(19) := '8A083032E4C8B1E0478A21312220B9D1E4C98B1157B274F91121CB8E342D362429B1E741004001F84440A02801814183F6346A144152A04B991E7D2A54A2D4A94FA33245AAD4E7D6A16003880DE07080D90106C78E4578F66C41B562050A982B40605BB3';
wwv_flow_api.g_varchar2_table(20) := '6FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C00000000190019000008A80011081C48B0A0C183070F283C80B0E1C0850B1D0E0440118040880A051AD868C060C58A083032E4C8B1E0478A21';
wwv_flow_api.g_varchar2_table(21) := '312220B9D1E4C98B1157B274F91121CB8E342D362429B1E7C1004003F84450A06801814183F6346A144152A04B991E7D2A54A2D4A94FA33245AAD4E7D6A160058815E09080590206C78E4578F66C41B562050E983B40605BB36FE122A04B17C15DB404E1';
wwv_flow_api.g_varchar2_table(22) := '92E53BD7EFDDB46BF712B6EBB627E1BA6009F29518100021F904030F0008002C00000000190019000008A80011081C48B0A0C1830701280480B0E1C0850B1D0E0C40318040880A051ED878C060C58A083032E4C8B1E0478A21312220B9D1E4C98B1157B2';
wwv_flow_api.g_varchar2_table(23) := '74F91121CB8E342D362429B1E741014005F84460A0A801814183F6346A144152A04B991E7D2A54A2D4A94FA33245AAD4E7D6A16007881DE0B080D90206C78E4578F66C41B5620512984B40605BB36FE122A04B17C15DB404E192E53BD7EFDDB46BF712B6';
wwv_flow_api.g_varchar2_table(24) := 'EBB627E1BA6009F2951810003B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(83529579376020676174)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_file_name=>'ajax-loader.gif'
,p_mime_type=>'image/gif'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '766172206D61696C67756E3D7B717569636B5069636B3A66756E6374696F6E28612C69297B72657475726E223C6120687265663D5C226A6176617363726970743A24282723222B612B2227292E76616C2827222B692B2227292E666F6375736F75742829';
wwv_flow_api.g_varchar2_table(2) := '3B5C223E222B692B223C2F613E227D2C6765745F73756767657374696F6E5F7374723A66756E6374696F6E28612C692C652C6E297B69662869297B76617220723D273C7370616E20636C6173733D226D61696C67756E5375636365737349636F6E206661';
wwv_flow_api.g_varchar2_table(3) := '2066612D636865636B222F3E273B72657475726E2065262628722B3D27203C7370616E20636C6173733D226D61696C67756E53756767657374696F6E223E2874686F7567682064696420796F75206D65616E20272B6D61696C67756E2E717569636B5069';
wwv_flow_api.g_varchar2_table(4) := '636B28612C65292B223F293C2F7370616E3E22292C727D72657475726E20653F273C7370616E20636C6173733D226D61696C67756E5175657374696F6E49636F6E2066612066612D7761726E696E67222F3E203C7370616E20636C6173733D226D61696C';
wwv_flow_api.g_varchar2_table(5) := '67756E53756767657374696F6E223E44696420796F75206D65616E20272B6D61696C67756E2E717569636B5069636B28612C65292B223F3C2F7370616E3E223A273C7370616E20636C6173733D226D61696C67756E4572726F7249636F6E206661206661';
wwv_flow_api.g_varchar2_table(6) := '2D636C6F7365222F3E3C7370616E20636C6173733D226D61696C67756E4572726F72223E272B6E2B223C2F7370616E3E227D2C76616C69646174696F6E5F696E5F70726F67726573733A66756E6374696F6E28612C69297B76617220653D2428612E7461';
wwv_flow_api.g_varchar2_table(7) := '72676574292E617474722822696422292C6E3D652B225F726573756C74223B617065782E64656275672822617065786D61696C67756E3A2076616C69646174696F6E5F696E5F70726F677265737320222B6E292C24282223222B6E292E68746D6C28223C';
wwv_flow_api.g_varchar2_table(8) := '696D6720636C6173733D276D61696C67756E4C6F6164696E6749636F6E27207372633D27222B692B22616A61782D6C6F616465722E67696627206865696768743D273136272F3E22292C617065782E64656275672822747269676765722076616C696461';
wwv_flow_api.g_varchar2_table(9) := '74696F6E696E70726F677265737322292C617065782E6A5175657279282223222B65292E74726967676572282276616C69646174696F6E696E70726F677265737322297D2C76616C69646174696F6E5F737563636573733A66756E6374696F6E28612C69';
wwv_flow_api.g_varchar2_table(10) := '2C65297B766172206E3D2428692E746172676574292E617474722822696422292C723D6E2B225F726573756C74223B617065782E64656275672822617065786D61696C67756E3A2076616C69646174696F6E5F7375636365737320222B72292C24282223';
wwv_flow_api.g_varchar2_table(11) := '222B72292E68746D6C286D61696C67756E2E6765745F73756767657374696F6E5F737472286E2C612E69735F76616C69642C612E6469645F796F755F6D65616E2C6529292C617065782E64656275672822747269676765722076616C69646174696F6E73';
wwv_flow_api.g_varchar2_table(12) := '75636365737322292C617065782E6A5175657279282223222B6E292E74726967676572282276616C69646174696F6E73756363657373222C7B646174613A617D297D2C76616C69646174696F6E5F6572726F723A66756E6374696F6E28612C69297B7661';
wwv_flow_api.g_varchar2_table(13) := '7220653D2428692E746172676574292E617474722822696422292C6E3D652B225F726573756C74223B617065782E64656275672822617065786D61696C67756E3A2076616C69646174696F6E5F6572726F7220222B6E292C24282223222B6E292E68746D';
wwv_flow_api.g_varchar2_table(14) := '6C28273C7370616E20636C6173733D226D61696C67756E4572726F7249636F6E2066612066612D636C6F7365222F3E203C7370616E20636C6173733D226D61696C67756E4572726F72223E272B612B223C2F7370616E3E22292C617065782E6465627567';
wwv_flow_api.g_varchar2_table(15) := '2822747269676765722076616C69646174696F6E6572726F7222292C617065782E6A5175657279282223222B65292E74726967676572282276616C69646174696F6E6572726F72222C7B6572726F724D6573736167653A617D297D2C6F6E5F6368616E67';
wwv_flow_api.g_varchar2_table(16) := '653A66756E6374696F6E2861297B76617220693D2428612E746172676574292E617474722822696422292C653D692B225F726573756C74223B617065782E64656275672822617065786D61696C67756E3A206F6E5F6368616E676520222B652B273D2227';
wwv_flow_api.g_varchar2_table(17) := '2B24282223222B69292E76616C28292B272227292C22223D3D24282223222B69292E76616C2829262628617065782E64656275672822636C656172696E6720726573756C7422292C24282223222B65292E68746D6C28222229297D2C696E69743A66756E';
wwv_flow_api.g_varchar2_table(18) := '6374696F6E28297B76617220613D746869732C693D612E6166666563746564456C656D656E74732C653D612E616374696F6E2E61747472696275746530312C6E3D612E616374696F6E2E61747472696275746530322C723D612E616374696F6E2E617474';
wwv_flow_api.g_varchar2_table(19) := '72696275746530332C743D612E616374696F6E2E61747472696275746530343B617065782E64656275672822617065786D61696C67756E3A206166666563746564456C656D656E74733A222B692E6C656E677468292C617065782E646562756728226170';
wwv_flow_api.g_varchar2_table(20) := '65786D61696C67756E3A20764170694B65793D222B65292C617065782E64656275672822617065786D61696C67756E3A207646696C655072656669783D222B6E293B666F722876617220733D303B733C692E6C656E6774683B732B2B297B76617220753D';
wwv_flow_api.g_varchar2_table(21) := '612E6166666563746564456C656D656E74732E65712873292C673D242875292E617474722822696422293B6966282259223D3D72297B617065782E64656275672822617065786D61696C67756E3A20616464696E6720726573756C74207370616E20222B';
wwv_flow_api.g_varchar2_table(22) := '67293B766172206C3D672B225F726573756C74223B242875292E616674657228223C7370616E20636C6173733D276D61696C67756E526573756C74272069643D27222B6C2B22273E3C2F7370616E3E22292C24282223222B67292E6368616E6765286675';
wwv_flow_api.g_varchar2_table(23) := '6E6374696F6E2861297B6D61696C67756E2E6F6E5F6368616E67652861297D297D617065782E64656275672822617065786D61696C67756E3A206170706C79696E67206D61696C67756E2076616C696461746F7220222B67292C242875292E6D61696C67';
wwv_flow_api.g_varchar2_table(24) := '756E5F76616C696461746F72287B6170695F6B65793A652C696E5F70726F67726573733A66756E6374696F6E2861297B6D61696C67756E2E76616C69646174696F6E5F696E5F70726F677265737328612C6E297D2C737563636573733A66756E6374696F';
wwv_flow_api.g_varchar2_table(25) := '6E28612C69297B6D61696C67756E2E76616C69646174696F6E5F7375636365737328612C692C74297D2C6572726F723A66756E6374696F6E28612C69297B6D61696C67756E2E76616C69646174696F6E5F6572726F7228612C69297D7D297D7D7D3B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(83529591844387310671)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_file_name=>'apexmailgun.min.js'
,p_mime_type=>'text/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2E6D61696C67756E526573756C74207B7D0D0A2E6D61696C67756E4C6F6164696E6749636F6E207B7D0D0A2E6D61696C67756E5375636365737349636F6E207B636F6C6F723A666F72657374677265656E3B666F6E742D73697A653A323270787D0D0A2E';
wwv_flow_api.g_varchar2_table(2) := '6D61696C67756E53756767657374696F6E207B7D0D0A2E6D61696C67756E5175657374696F6E49636F6E207B636F6C6F723A6F72616E67653B666F6E742D73697A653A323270787D0D0A2E6D61696C67756E4572726F7249636F6E207B636F6C6F723A72';
wwv_flow_api.g_varchar2_table(3) := '65643B666F6E742D73697A653A323270787D0D0A2E6D61696C67756E4572726F72207B636F6C6F723A7265647D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(83529604234402931800)
,p_plugin_id=>wwv_flow_api.id(83529544388083634568)
,p_file_name=>'apexmailgun.css'
,p_mime_type=>'text/css'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
